**    ModelEco : MODELling in mathematical programming for the ECOnomic analysis of agriculture    **

*-----------------------------------------------------------------------------*
$Ontext
Name             modelEco_rotation1.gms
Sequence         2 - The farm model
Type             LP
GAMS language    SUBSET

Description
Source: INOSYS network of chambers of agriculture in the Centre Val de Loire region

An arable crop farmer growing special crops in the Centre-Val de Loire region has 110 ha of land.
Irrigation and the economic environment of his farm offer him a large range of production options:
soft wheat, durum wheat, spring barley, potatoes for human consumption, sugar beets and rapeseed.
Five of these crop types are irrigated in order to ensure high quality regular production.
The farmer has 60 000 m3 of water.
Irrigation needs and economic data are shown in the table below:

Irrigation
Crops                           Vol in m3/ha
Soft wheat                           175
Durum wheat                          350
Spring barley                        700
Potato for human consumption        1800
Sugar beet                          1750

Technico-economic data
Crops                          Yields  (qx/ha)           Prices/qx ()            Total costs (/ha)
Soft wheat                           85                      16                       460
Durum wheat                          71                      28                       565
Spring barley                        70                      17.5                     470
Potato for human consumption        495                      14                      4210
Sugar beet                          950                       2.6                    1082
Rapeseed                             40                      38                       490

For agronomic reasons,
 Oilseed crops cannot be grown more than once every three years on the same plot,
 cereal crops cannot be grown two years in a row on the same plot,
 and sugar beets or potatoes can only be cultivated once every six years.

What is the optimum crop pattern for this farmer ? What is his optimum income ?"



$Offtext


*----------                          DECLARATIONS                        ----------*
sets
C crops        /S_Wheat, D_Wheat, Sugar_beet, Rapeseed, Potato, Spring_barley/
Oilseed(C)     /Rapeseed/
Cere(C)        /S_Wheat, D_Wheat, Spring_barley/
SbP(C)         /Sugar_beet, Potato/
;

*----------                          DATA                        ----------*
scalar
LAND_A     land availability in hectares                         /110/
WATER_A    water availability                                    /60000/

Duration    rotation duration                                    /6/
maxOilseed  maximum number of years for oilseed crops            /2/
maxCere     maximum number of years for cereal crops             /4/
MaxSbP      maximum number of years for sugar beets and potatoes /1/
;


parameter Water_N(C) water needs per crop and technology (m3 per ha)
/S_Wheat         175
 D_Wheat         350
 Sugar_beet     1750
 Rapeseed          0
 Potato         1800
 Spring_barley   700/
;

parameter
Yield (C) yield per crop in quintals per ha
/S_Wheat          85
 D_Wheat          71
 Sugar_beet      950
 Rapeseed         40
 Potato          495
 Spring_barley    70/
;

parameter
PC (C) selling price per crop in euros
/S_Wheat          16
 D_Wheat          28
 Sugar_beet        2.6
 Rapeseed         38
 Potato           14
 Spring_barley    17.5/
;

parameter
Cost (C) variable cost per crop in euros per ha
/S_Wheat           460
 D_Wheat           565
 Sugar_beet       1082
 Rapeseed          490
 Potato           4210
 Spring_barley     470/
;

parameter
GM(C) gross margin per crop in euros    ;
GM(C) = Yield(C)*PC(C)-Cost(C);

display GM ;
*----------                         MODEL                          ----------*
variables
Z    total farm income (euros)
;

positive variables
X     area per crop (hectares)
;

equations
OBJECTIVE      objective function
LAND           land equation
WATER          irrigation equation
Rot_Oilseed
Rot_Cere
Rot_SbP
;

OBJECTIVE..         sum (C, GM(C)* X(C)) =E= Z ;

LAND..              sum(C, X(C)) =l= LAND_A  ;

WATER..             sum(C, Water_N(C)*X(C)) =l= WATER_A  ;

Rot_Oilseed..       sum(Oilseed, X(Oilseed)) =l= sum(C, X(C))* maxOilseed /Duration ;

Rot_Cere..          sum(cere, X(cere)) =l= sum(C, X(C))*maxCere/Duration ;

Rot_SbP..           sum(SbP, X(SbP)) =l= sum(C, X(C))*MaxSbP/Duration ;


model modelS2 first example /all/;

*----------                        SOLUTION                         ----------*
solve modelS2 using LP maximizing Z;





